==> issetbv-video-archive-filehandler-client-0.2.4-64a990.zip: IssetBV/FileHandlerClient/File/Files.php <==
<?php
namespace IssetBV\FileHandlerClient\File;

use GuzzleHttp\Client as GuzzleClient;
use IssetBV\FileHandlerClient\File\Location\LocationInterface;

class Files
{

    /**
     * @var GuzzleClient
     */
    private $client;

    /**
     * 
     * @var array
     */
    private $defaultDivisions;

    /**
     * @param GuzzleClient $client
     * @param array $defaultDivisions
     */
    public function __construct(GuzzleClient $client, array $defaultDivisions = array())
    {
        $this->defaultDivisions = $defaultDivisions;
        $this->client = $client;
    }

    /**
     * 
     * @param string $query
     * @param array $divisions
     * @return multitype:\IssetBV\FileHandlerClient\File\File
     */
    public function search($query, array $divisions = null)
    {
        if ($divisions === null) {
            $divisions = $this->defaultDivisions;
        }
        
        $data = $this->client->get('file/search', [
            'query' => [
                'divisions' => $divisions,
                'q' => $query
            ]
        ])
            ->getBody()
            ->getContents();
        $return = array();
        foreach (json_decode($data) as $fileData) {
            $return[] = new File($this->client, $fileData);
        }
        return $return;
    }

    /**
     * 
     * @param string $uuid
     * @param array $divisions 
     * @return \IssetBV\FileHandlerClient\File\File
     */
    public function get($uuid, array $divisions = null)
    {
        if ($divisions === null) {
            $divisions = $this->defaultDivisions;
        }
        
        $data = $this->client->get('file/' . $uuid, [
            'query' => [
                'divisions' => $divisions
            ]
        ])
            ->getBody()
            ->getContents();
        return new File($this->client, $data);
    }

    /**
     * 
     * @param string $name
     * @param LocationInterface $locationSource
     * @param string $folderUuid
     * @return \IssetBV\FileHandlerClient\File\File
     */
    public function add($name, LocationInterface $locationSource, $folderUuid = null, $preview = true)
    {
        $data = $this->client->post('file', [
            'json' => [
                'name' => $name,
                'location_source' => $locationSource->toArray(),
                'folder_uuid' => $folderUuid,
                'preview' => $preview,
            ]
        ])
            ->getBody()
            ->getContents();
        return new File($this->client, $data);
    }
}

==> issetbv-video-archive-filehandler-client-0.3.2-385567.zip: IssetBV/FileHandlerClient/File/Files.php <==
<?php
namespace IssetBV\FileHandlerClient\File;

use GuzzleHttp\Client as GuzzleClient;
use IssetBV\FileHandlerClient\File\Location\LocationInterface;

class Files
{

    /**
     * @var GuzzleClient
     */
    private $client;

    /**
     * 
     * @var array
     */
    private $defaultDivisions;

    /**
     * @param GuzzleClient $client
     * @param array $defaultDivisions
     */
    public function __construct(GuzzleClient $client, array $defaultDivisions = array())
    {
        $this->defaultDivisions = $defaultDivisions;
        $this->client = $client;
    }

    public function getFailed(array $divisions = null)
    {
        if ($divisions === null) {
            $divisions = $this->defaultDivisions;
        }
        
        $data = json_decode($this->client->get('files/failed', [
            'query' => [
                'divisions' => $divisions
            ]
        ])
            ->getBody()
            ->getContents());
        $return = array();
        foreach ($data as $fileData) {
            $return[] = new File($this->client, $fileData);
        }
        return $return;
    }

    public function getUsage(array $divisions = null)
    {
        if ($divisions === null) {
            $divisions = $this->defaultDivisions;
        }
        
        $data = $this->client->get('file/usage', [
            'query' => [
                'divisions' => $divisions
            ]
        ])
            ->getBody()
            ->getContents();
        
        return json_decode($data);
    }

    /**
     * 
     * @param string $query
     * @param array $divisions
     * @return multitype:\IssetBV\FileHandlerClient\File\File
     */
    public function search($query, array $divisions = null)
    {
        if ($divisions === null) {
            $divisions = $this->defaultDivisions;
        }
        
        $data = $this->client->get('file/search', [
            'query' => [
                'divisions' => $divisions,
                'q' => $query
            ]
        ])
            ->getBody()
            ->getContents();
        return json_decode($data);
    }

    /**
     * 
     * @param string $uuid
     * @param array $divisions 
     * @return \IssetBV\FileHandlerClient\File\File
     */
    public function get($uuid, array $divisions = null)
    {
        if ($divisions === null) {
            $divisions = $this->defaultDivisions;
        }
        
        $data = $this->client->get('file/' . $uuid, [
            'query' => [
                'divisions' => $divisions
            ]
        ])
            ->getBody()
            ->getContents();
        return new File($this->client, $data);
    }

    public function multi(array $files, array $divisions = null)
    {
        if ($divisions === null) {
            $divisions = $this->defaultDivisions;
        }
        
        $files = json_decode($this->client->get('files/multi', [
            'query' => [
                'divisions' => $divisions,
                'files' => $files
            ]
        ])
            ->getBody()
            ->getContents());
        
        $return = [];
        foreach ($files as $file) {
            $return[] = new File($this->client, $file);
        }
        
        return $return;
    }

    /**
     * 
     * @param string $name
     * @param LocationInterface $locationSource
     * @param string $folderUuid
     * @return \IssetBV\FileHandlerClient\File\File
     */
    public function add($name, LocationInterface $locationSource, $folderUuid = null, $preview = true)
    {
        $data = $this->client->post('file', [
            'json' => [
                'name' => $name,
                'location_source' => $locationSource->toArray(),
                'folder_uuid' => $folderUuid,
                'preview' => $preview
            ]
        ])
            ->getBody()
            ->getContents();
        return new File($this->client, $data);
    }
}
